# Satsure DS Common Utils

Repository containing common utilities used across the data science team of SatSure.

# Folders & Files:
- `./satsure_ds_utils`: Core components of DS Utils.
- `./examples`: Folder containing examples
- `main.py`: main file for testing.
- `requirements.txt`: Python requirements file.
- `setup.py`: Setup file for pip wheel.

# List of Algorithms/Operations:
- Split Raster
- Join Raster
- Array to Raster
- FastTile
- FastTile NDVI
- LULC Area
- Village Geo Area
- Clip to Boundary
